import Link from "next/link";
import { useRouter } from "next/router";
import { useState } from "react";
import PageTitle from "../components/PageTitle";
import Head from "next/head";
import Container from "../components/Container";
import { useBecomeSellerMutation } from "../app/features/sellers/apiSlice";
import useLanguage from "../hooks/useLanguage";
import { useDispatch, useSelector } from "react-redux";
import { authModalSet } from "../app/features/auth/authSlice";
function BecomeSeller() {
  const router = useRouter();
  const [data, setData] = useState({
    email: "",
    phone: "",
    shop_name: "",
    address: "",
    banner_image: "",
    prev_banner_image: "",
    open_at: "10.00AM",
    closed_at: "10.00PM",
    agree_terms_condition: "",
    logo: "",
    prev_logo: "",
  });

  const textHandler = (e) => {
    setData((prev) => ({ ...prev, [e.target.name]: e.target.value }));
  };
  textHandler.bind(this);

  const imgChangHandler = (e) => {
    if (e.target.value !== "") {
      const imgReader = new FileReader();
      imgReader.onload = (event) => {
        setData((prev) => ({
          ...prev,
          ["prev_" + e.target.name]: event.target.result,
        }));
      };
      imgReader.readAsDataURL(e.target.files[0]);
      setData((prev) => ({ ...prev, [e.target.name]: e.target.files[0] }));
    }
  };
  imgChangHandler.bind(this);

  const rememberMe = (e) => {
    setData((prev) => ({
      ...prev,
      [e.target.name]: !prev.agree_terms_condition,
    }));
  };
  rememberMe.bind(this);

  // handle submit
  const [becomeSeller] = useBecomeSellerMutation();
  const dispatch = useDispatch();
  const handleSubmit = (e) => {
    e.preventDefault();
    becomeSeller({
      data: data,
      router: router,
      loginHandler: () => dispatch(authModalSet("login")),
    });
  };

  handleSubmit.bind(this);
  const language = useLanguage();
  return (
    <>
      <Head>
        <title className="notranslate">{language["Become a seller"]}</title>
      </Head>
      <PageTitle
        title={language["Become a seller"]}
        pageName={language["Become a seller"]}
      />
      <section className="lg:py-20 py-3 bg-slate-50 ">
        <Container>
          <div className="grid grid-cols-1 lg:grid-cols-12 bg-white p-3 sm:p-[30px] gap-12">
            <div className="lg:col-span-9">
              <div className="w-full mb-4">
                <h1 className="text-[22px] font-semibold text-slate-900 mb-1 notranslate">
                  {language["Seller Information"]}
                </h1>
                <p className="text-[15px] text-slate-400 notranslate">
                  {
                    language[
                      "Fill the form below or write us We will help you as soon as possible"
                    ]
                  }
                </p>
              </div>
              <div className=" w-full h-full">
                <form className="flex gap-5 flex-col" onSubmit={handleSubmit}>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate "
                      for="email"
                    >
                      {language["Email Address"]}*
                    </label>
                    <input
                      placeholder="Email"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="email"
                      id="email"
                      name="email"
                      value={data.email}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="phone"
                    >
                      {language["Phone"]}*
                    </label>
                    <input
                      placeholder="+09007733668"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="tel"
                      id="phone"
                      name="phone"
                      value={data.phone}
                      onChange={textHandler}
                    />
                  </div>
                  <div className="w-full mb-4">
                    <h1 className="text-[22px] font-semibold text-slate-900 mb-1 notranslate">
                      {language["Shop Information"]}
                    </h1>
                    <p className="text-[15px] text-slate-400">
                      {
                        language[
                          "Fill the form below or write us We will help you as soon as possible"
                        ]
                      }
                    </p>
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="shop_name"
                    >
                      {language["Shop Name"]}*
                    </label>
                    <input
                      placeholder="Name"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="shop_name"
                      name="shop_name"
                      value={data.shop_name}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="address"
                    >
                      {language["Address"]}*
                    </label>
                    <input
                      placeholder="Address"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="address"
                      name="address"
                      value={data.address}
                      onChange={textHandler}
                    />
                  </div>
                </form>
              </div>
            </div>
            {/* right side */}
            <div className=" lg:col-span-3">
              <div>
                <h1 className="text-xl tracking-wide font-bold text-slate-900 mb-2 notranslate">
                  {language["Update Logo"]}
                </h1>
                <p className="text-sm text-slate-400 mb-5 notranslate">
                  {language["Profile of at least Size"]}
                  <span className="ml-1 text-slate-500">300x300</span>.{" "}
                  {language["Gifs work too"]}.
                  <span className="ml-1 text-slate-500">
                    {language["Max 5mb"]}
                  </span>
                  .
                </p>

                <div className="relative w-full flex justify-center">
                  <div className="w-[130px] h-[130px] bg-slate-600 rounded-full flex justify-center items-center overflow-hidden">
                    {data.prev_logo ? (
                      <img src={data.prev_logo} alt="" />
                    ) : (
                      <h1 className="text-3xl text-white font-bold notranslate">
                        {language["logo"]}
                      </h1>
                    )}
                  </div>
                  <label
                    htmlFor="shop_image"
                    className="w-[32px] h-[32px] absolute bottom-0 right-[50px] hover:bg-[#F539F8] bg-[#F539F8] rounded-full cursor-pointer"
                  >
                    <svg
                      width="32"
                      height="32"
                      viewBox="0 0 32 32"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <path
                        d="M16.5147 11.5C17.7284 12.7137 18.9234 13.9087 20.1296 15.115C19.9798 15.2611 19.8187 15.4109 19.6651 15.5683C17.4699 17.7635 15.271 19.9587 13.0758 22.1539C12.9334 22.2962 12.7948 22.4386 12.6524 22.5735C12.6187 22.6034 12.5663 22.6296 12.5213 22.6296C11.3788 22.6334 10.2362 22.6297 9.09365 22.6334C9.01498 22.6334 9 22.6034 9 22.536C9 21.4009 9 20.2621 9.00375 19.1271C9.00375 19.0746 9.02997 19.0109 9.06368 18.9772C10.4123 17.6249 11.7609 16.2763 13.1095 14.9277C14.2295 13.8076 15.3459 12.6913 16.466 11.5712C16.4884 11.5487 16.4997 11.5187 16.5147 11.5Z"
                        fill="white"
                      ></path>
                      <path
                        d="M20.9499 14.2904C19.7436 13.0842 18.5449 11.8854 17.3499 10.6904C17.5634 10.4694 17.7844 10.2446 18.0054 10.0199C18.2639 9.76139 18.5261 9.50291 18.7884 9.24443C19.118 8.91852 19.5713 8.91852 19.8972 9.24443C20.7251 10.0611 21.5492 10.8815 22.3771 11.6981C22.6993 12.0165 22.7105 12.4698 22.3996 12.792C21.9238 13.2865 21.4443 13.7772 20.9686 14.2717C20.9648 14.2792 20.9536 14.2867 20.9499 14.2904Z"
                        fill="white"
                      ></path>
                    </svg>
                  </label>
                  <input
                    type="file"
                    name="logo"
                    onChange={imgChangHandler}
                    className="opacity-0 absolute"
                    id="shop_image"
                  />
                </div>
              </div>
              <div className=" mt-14">
                {" "}
                <h1 className="text-xl tracking-wide font-bold text-slate-900 mb-2 notranslate">
                  {language["Update Cover"]}
                </h1>
                <p className="text-sm text-slate-400 mb-5 notranslate">
                  {language["Cover of at least Size"]}
                  <span className="ml-1 text-slate-500">1170x920.</span>
                </p>
                <div className="relative w-full flex justify-center">
                  <div className="w-full h-fit bg-slate-600 rounded flex justify-center items-center overflow-hidden">
                    <img
                      src={
                        data.prev_banner_image
                          ? data.prev_banner_image
                          : "./img/seller/become_seller_banner.webp"
                      }
                      className=" object-cover bg-no-repeat max-h-[122px] w-full "
                      alt=""
                    />
                  </div>
                  <label
                    htmlFor="banner_image"
                    className="w-[32px] h-[32px] absolute bottom-0 right-0 hover:bg-[#F539F8] bg-[#F539F8] rounded-full cursor-pointer"
                  >
                    <svg
                      width="32"
                      height="32"
                      viewBox="0 0 32 32"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <path
                        d="M16.5147 11.5C17.7284 12.7137 18.9234 13.9087 20.1296 15.115C19.9798 15.2611 19.8187 15.4109 19.6651 15.5683C17.4699 17.7635 15.271 19.9587 13.0758 22.1539C12.9334 22.2962 12.7948 22.4386 12.6524 22.5735C12.6187 22.6034 12.5663 22.6296 12.5213 22.6296C11.3788 22.6334 10.2362 22.6297 9.09365 22.6334C9.01498 22.6334 9 22.6034 9 22.536C9 21.4009 9 20.2621 9.00375 19.1271C9.00375 19.0746 9.02997 19.0109 9.06368 18.9772C10.4123 17.6249 11.7609 16.2763 13.1095 14.9277C14.2295 13.8076 15.3459 12.6913 16.466 11.5712C16.4884 11.5487 16.4997 11.5187 16.5147 11.5Z"
                        fill="white"
                      ></path>
                      <path
                        d="M20.9499 14.2904C19.7436 13.0842 18.5449 11.8854 17.3499 10.6904C17.5634 10.4694 17.7844 10.2446 18.0054 10.0199C18.2639 9.76139 18.5261 9.50291 18.7884 9.24443C19.118 8.91852 19.5713 8.91852 19.8972 9.24443C20.7251 10.0611 21.5492 10.8815 22.3771 11.6981C22.6993 12.0165 22.7105 12.4698 22.3996 12.792C21.9238 13.2865 21.4443 13.7772 20.9686 14.2717C20.9648 14.2792 20.9536 14.2867 20.9499 14.2904Z"
                        fill="white"
                      ></path>
                    </svg>
                  </label>
                  <input
                    type="file"
                    name="banner_image"
                    onChange={imgChangHandler}
                    className="opacity-0 absolute"
                    id="banner_image"
                  />
                </div>
              </div>
            </div>
            <div className="lg:col-span-9">
              <div className="remember-checkbox flex items-start space-x-2.5 mb-5">
                <button
                  type="button"
                  name="agree_terms_condition"
                  onClick={rememberMe}
                  className="w-5 h-5 text-slate-900 flex justify-center items-center border border-light-gray mt-1"
                >
                  {data.agree_terms_condition ? (
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      className="h-5 w-5 pointer-events-none"
                      viewBox="0 0 20 20"
                      fill="currentColor"
                    >
                      <path
                        fill-rule="evenodd"
                        d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z"
                        clip-rule="evenodd"
                      ></path>
                    </svg>
                  ) : null}
                </button>
                <span className="text-base text-black cursor-pointer notranslate">
                  {language["I agree all terms and condition in M-Express"]}
                </span>
              </div>
              <div className="w-full flex justify-center">
                <button
                  type="submit"
                  className="mt-6 self-center bg-dark-300 text-white font-medium text-base py-4 px-8  rounded-lg text-center inline-block transition hover:bg-dark-300/90 w-full max-w-[500px] notranslate"
                >
                  {language["Become a seller"]}
                </button>
              </div>
              <div className="flex w-full justify-center notranslate mt-3">
                <a className="/" href="#" target="blank">
                  {language["Already have an Account?Log In"]}
                </a>
              </div>
            </div>
          </div>
        </Container>
      </section>
    </>
  );
}
export default BecomeSeller;
